@@ -562,8 +562,9 @@ void MainWindow::onShoot(int x, int y) {
     if ( !shotlimiter_ ) {
         Bullet* tmpbullet = new Bullet;
 
-        if ( (x > hero_->x() && hero_->getDirection()) ||
-             (x < hero_->x() && hero_->getDirection() == 0 ) ) {
+        if ( x < 1000 &&
+             ((x > hero_->x() && hero_->getDirection()) ||
+             (x < hero_->x() && hero_->getDirection() == 0 )) ) {
             return;
         }
 
