@@ -67,6 +67,15 @@ void MyGfxView::mousePressEvent(QMouseEvent *event) {
     }
 }
 
+// Keyboard
+void MyGfxView::keyPressEvent(QKeyEvent *event) {
+    if ( state_ == RUNNING ) {
+        if ( event->key() == Qt::Key_Space ) {
+            emit shoot(1000, 1000);
+        }
+    }
+}
+
 void MyGfxView::setState(Gamestate state) {
     state_ = state;
 }
